@@ -15,7 +15,11 @@
 #'@param dec The precision of the data, which defaults to 2 decimal places.
 #'@param nonnormal When the data belongs to a non-normal distribution, this parameter is needed to indicate which is variable is non-normally distributed.
 #'@param type The type of encoding generally does not require input.
+#'@param statistic Statistical effect values. Usually, it is the default F, and selecting T will return a statistical effect value.
+#'@param atotest Check if the data is normally distributed. The default is T.
+#'@param NormalTest A method for detecting whether data is normally distributed.The default values are Kolmogorov Smirnov test and Kolmogorov Smirnov test.Other options are: "ad", "cvm", "pearson".
 #'@importFrom "stringi" "stri_escape_unicode" "stri_escape_unicode"
+#'
 #'@return A data frame.
 
 utils::globalVariables(c('aov',
@@ -25,15 +29,17 @@ utils::globalVariables(c('aov',
 
 
 
-sci1mean<- function(mvars,x,data,dec,nonnormal=NULL,type=NULL) {
+sci1mean<- function(mvars,x,data,dec,nonnormal=NULL,type=NULL,statistic=NULL,atotest=NULL,NormalTest=NULL) {
   mvars<-mvars;x<-x;data<-data;nonnormal<-nonnormal;type<-type
+  NormalTest<-NormalTest
   if (missing(dec)) {dec<-2} else {dec<-dec}
   xvt<-data[,x];nc<-length(mvars);varsdt<-data[,mvars];
   if (nc==1) varsdt<-as.matrix(varsdt,ncol=nc)
   n.x<-length(levels(factor(xvt)));
   queshiliebiao<-is.na(cbind(xvt,varsdt))
-  pp<-NULL; st.diff<-NULL;d0<-NULL
+  pp<-NULL; st.diff<-NULL;d0<-NULL;sv<-NULL
   jia<-code(type=type)
+  ntp<-999
   for (i in (1:nc)) {
     scimean<-tapply(varsdt[,i],factor(xvt),average)
     scistd<-tapply(varsdt[,i],factor(xvt),stdev)
@@ -43,28 +49,41 @@ sci1mean<- function(mvars,x,data,dec,nonnormal=NULL,type=NULL) {
     scimax<-numfmt(tapply(varsdt[,i],factor(xvt),mxmax),dec)
     sciq1<-numfmt(tapply(varsdt[,i],factor(xvt),mxq1),dec)
     sciq3<-numfmt(tapply(varsdt[,i],factor(xvt),mxq3),dec)
+    if (atotest==T) {ntp<-nt(varsdt[,i],kind = NormalTest)}
     scitmp<-xvt[apply(queshiliebiao[,c(1,i+1)],1,sum)==0]  #取没有缺失的数据
     if (length(levels(factor(scitmp)))>1) {
-      pvalue<-summary(aov(varsdt[,i]~factor(xvt)))[[1]]$"Pr(>F)"[1]
-      pp1<-ifelse(pvalue<0.001, "<0.001",pvformat(pvalue,3))
+      pvalue<-summary(aov(varsdt[,i]~factor(xvt)))[[1]]$"Pr(>F)"[1];svv1<-summary(aov(varsdt[,i]~factor(xvt)))[[1]]$"F value"[1]
+      pp1<-ifelse(pvalue<0.001, "<0.001",pvformat(pvalue,3));sv1<-ifelse(svv1<0.001, "<0.001",pvformat(svv1,3))
     }
     if (length(levels(factor(scitmp)))>1) {
-      pvalue.npr<-kruskal.test(varsdt[,i]~factor(xvt))$p.value
-      pp1.npr<-ifelse(pvalue.npr<0.001, "<0.001",pvformat(pvalue.npr,3))}
+      pvalue.npr<-kruskal.test(varsdt[,i]~factor(xvt))$p.value;svv2<-kruskal.test(varsdt[,i]~factor(xvt))[["statistic"]]
+      pp1.npr<-ifelse(pvalue.npr<0.001, "<0.001",pvformat(pvalue.npr,3))
+      sv1.npr<-ifelse(svv2<0.001, "<0.001",pvformat(svv2,3))
+    }
     if (!mvars[i] %in% nonnormal) {
       d1<-paste(numfmt(scimean,dec),jia,numfmt(scistd,dec),sep="")
-      p<-pp1
+      p<-pp1;sv0<-sv1
+    }
+    if (ntp<0.05) {
+      d1<-paste(scimedian," (",sciq1,"-",sciq3,")",sep="")
+      p<-pp1.npr;sv0<-sv1.npr
     }
     if (mvars[i] %in% nonnormal) {
       d1<-paste(scimedian," (",sciq1,"-",sciq3,")",sep="")
-      p<-pp1.npr
+      p<-pp1.npr;sv0<-sv1.npr
     }
-    d0<-rbind(d0,d1);pp<-rbind(pp,p)
+    d0<-rbind(d0,d1);pp<-rbind(pp,p);sv<-rbind(sv,sv0)
   }
   dd<-rbind(scinn,d0)
   tmp.cname<-paste(x,".",levels(factor(xvt)),sep="")
-  dd1<-cbind(dd,c("",pp))
+  if (statistic==T) {
+    dd1<-cbind(dd,c("",sv),c("",pp))
+  } else {dd1<-cbind(dd,c("",pp))}
   dd2<-cbind(c("N",mvars),dd1)
-  colnames(dd2)<-c("Characteristic",tmp.cname,"p value")
+  if (statistic==T) {
+    colnames(dd2)<-c("Characteristic",tmp.cname,"statistical value","p value")
+  } else {colnames(dd2)<-c("Characteristic",tmp.cname,"p value")}
   dd2
 }
+
+
